AdapterManager

Struct AdapterManager 

pub struct AdapterManager { /* private fields */ }
Adapter Manager

Implementations

Source

impl AdapterManager

pub fn new() -> Self

Create a new adapter manager

pub fn register_export_adapter( &mut self, target: CompilationTarget, adapter: Box<dyn ExportAdapter>, ) -> Result<()>

Register export adapter

Parameters
  • target - Compilation target
  • adapter - Export adapter to register
Return Value

Returns Ok(()) on success, or an error message on failure.

pub fn register_import_adapter( &mut self, target: CompilationTarget, adapter: Box<dyn ImportAdapter>, ) -> Result<()>

Register import adapter

Parameters
  • target - Compilation target
  • adapter - Import adapter to register
Return Value

Returns Ok(()) on success, or an error message on failure.

pub fn get_export_adapter( &self, target: &CompilationTarget, ) -> Result<&dyn ExportAdapter>

Get export adapter

Parameters
  • target - Compilation target
Return Value

Returns adapter reference if found, or an error otherwise.

pub fn get_export_adapter_mut( &mut self, target: &CompilationTarget, ) -> Result<&mut (dyn ExportAdapter + '_)>

Get mutable export adapter

Parameters
  • target - Compilation target
Return Value

Returns mutable adapter reference if found, or an error otherwise.

pub fn get_import_adapter( &self, target: &CompilationTarget, ) -> Result<&dyn ImportAdapter>

Get import adapter

Parameters
  • target - Compilation target
Return Value

Returns adapter reference if found, or an error otherwise.

pub fn get_import_adapter_mut( &mut self, target: &CompilationTarget, ) -> Result<&mut (dyn ImportAdapter + '_)>

Get mutable import adapter

Parameters
  • target - Compilation target
Return Value

Returns mutable adapter reference if found, or an error otherwise.

pub fn list_supported_targets(&self) -> Vec<CompilationTarget>

List all supported compilation targets

Return Value

List of compilation targets

pub fn cleanup_all(&mut self) -> Result<()>

Clean up all adapter resources

Return Value

Returns Ok(()) on success, or an error message on failure.