Backend

Trait Backend 

pub trait Backend {
    // Required methods
    fn name(&self) -> &'static str;
    fn primary_target(&self) -> CompilationTarget;
    fn artifact_type(&self) -> ArtifactType;
    fn match_score(&self, target: &CompilationTarget) -> f32;
    fn generate(
        &self,
        program: &GaiaModule,
        config: &GaiaConfig,
    ) -> Result<GeneratedFiles>;
}
Backend compiler trait

Required Methods

fn name(&self) -> &'static str

Get backend name

fn primary_target(&self) -> CompilationTarget

Get the primary compilation target supported by this backend.

fn artifact_type(&self) -> ArtifactType

Get the type of artifact generated by this backend.

fn match_score(&self, target: &CompilationTarget) -> f32

Calculate the match score (0-100) for the given compilation target. A score of 0 indicates that the target is not supported.

fn generate( &self, program: &GaiaModule, config: &GaiaConfig, ) -> Result<GeneratedFiles>

Compile Gaia program to target platform

Implementors