Modules
- emitter
- x86
- Native x86 backend compiler for Windows This backend generates native x86 machine code wrapped in a PE container
- x86_64
- Native x86_64 backend compiler for Windows This backend generates native x86_64 machine code wrapped in a PE container
Structs
- Windows
Backend - Windows Backend implementation (Native PE)